Attribute VB_Name = "mBCE"
Private Declare Function GetPrivateProfileString Lib "kernel32.dll" Alias "GetPrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Private Declare Function WritePrivateProfileString Lib "kernel32.dll" Alias "WritePrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal lpString As String, ByVal lpFileName As String) As Long
Private Declare Function GetPrivateProfileInt Lib "kernel32.dll" Alias "GetPrivateProfileIntA" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal nDefault As Long, ByVal lpFileName As String) As Long

Function CodabarCheckDigit(Barcode As String) As String
' MacroName: CodabarCheckDigit
' MacroDescription: Calculates check digits for library Codabar barcodes
' by Harvey E. Hahn -- 3 Feb 2000
'
' Based on an alternate digits algorithm found in Martin L. Rubin (ed.),
' "Handbook of data processing management," v. 5, p. 58
' (New York : Petrocelli Books, 1971)
'
' The algorithm is also available at this URL:
' <http://www.semiconductor.agilent.com/barcode/sg/Misc/msi_code.html>
'
' Copyright (C) 2000 by Arlington Heights Memorial Library.  Libraries
' may freely use and adapt this macro with due credit.  Commercial use
' prohibited without written permission.
'

   Dim odd As String
   Dim even As String
   Dim oddval As Long
   Dim evenval As Long
   Dim total As Integer
   Dim unitsdigit As Integer
   Dim checkdigit As Integer
   Dim i As Integer
   Dim p As Integer
   '
   ' remove any internal spaces in entered barcode:
   ' [unnecessary if entered data is guaranteed to be space-free]
   p = InStr(Barcode, " ")
   Do While p > 0
      Barcode = Left$(Barcode, p - 1) & Mid$(Barcode, p + 1)
      p = InStr(Barcode, " ")
   Loop
   '
   ' create sequence of barcode digits in odd positions: [units position is odd]
   odd = ""
   For i = Len(Barcode) To 1 Step -2    'go from right to left
      odd = Mid$(Barcode, i, 1) & odd
   Next i
   '
   ' create sequence of barcode digits in even positions: [units position is odd]
   even = ""
   For i = Len(Barcode) - 1 To 1 Step -2 'go from right to left
      even = Mid$(Barcode, i, 1) & even
   Next i
   '
   ' manipulate odd digit sequence by multiplying its value by 2:
   oddval = Val(odd): oddval = 2 * oddval
   odd = Trim$(Str$(oddval))
   '
   ' add digits of manipulated odd digit sequence:
   oddval = 0
   For i = 1 To Len(odd)
   oddval = oddval + Val(Mid$(odd, i, 1))
   Next i
   '
   ' add digits of even digit sequence:
   ' [this could have been combined with the creation of the even
   ' digit sequence above, but the algorithm is clearer this way]
   evenval = 0
   For i = 1 To Len(even)
   evenval = evenval + Val(Mid$(even, i, 1))
   Next i
   '
   ' calculate check digit:
   total = oddval + evenval
   unitsdigit = total Mod 10
   If unitsdigit = 0 Then unitsdigit = 10
   checkdigit = 10 - unitsdigit   '
   CodabarCheckDigit = Trim$(Str$(checkdigit))
End Function

Sub GetIni(BarcodeType$, LibraryCode$, PatronCode$, ItemCode$)
  bcpath = App.Path
  BarcodeType$ = Space(255)
  LibraryCode$ = Space(255)
  slength = GetPrivateProfileString("Default", "BarcodeType", "0", BarcodeType$, 255, bcpath + "\bcexpndr.ini")
  BarcodeType$ = Left(BarcodeType$, slength)
  BarcodeType$ = Left(BarcodeType$ + "0", 1)
  slength = GetPrivateProfileString("Default", "LibraryCode", "0000", LibraryCode$, 255, bcpath + "\bcexpndr.ini")
  LibraryCode$ = Left(LibraryCode$, slength)
  LibraryCode$ = Left(LibraryCode$ + "0000", 4)
  slength = GetPrivateProfileString("Default", "PatronCode", "0", PatronCode$, 255, bcpath + "\bcexpndr.ini")
  PatronCode$ = Left(PatronCode$, slength)
  PatronCode$ = Left(PatronCode$ + "0", 1)
  slength = GetPrivateProfileString("Default", "ItemCode", "0", ItemCode$, 255, bcpath + "\bcexpndr.ini")
  ItemCode$ = Left(ItemCode$, slength)
  ItemCode$ = Left(ItemCode$ + "0", 1)
End Sub

Sub WriteIni(BarcodeType$, LibraryCode$, PatronCode$, ItemCode$)
  bcpath = App.Path
  Dim retval As Long
  retval = WritePrivateProfileString("Default", "BarcodeType", BarcodeType$, bcpath + "\bcexpndr.ini")
  retval = WritePrivateProfileString("Default", "LibraryCode", LibraryCode$, bcpath + "\bcexpndr.ini")
  retval = WritePrivateProfileString("Default", "PatronCode", PatronCode$, bcpath + "\bcexpndr.ini")
  retval = WritePrivateProfileString("Default", "ItemCode", ItemCode$, bcpath + "\bcexpndr.ini")
End Sub
